KV class

Annotations
  • @collection
  • @Name.new('kv')

Constructors

KV()

Properties

expiresAt ↔ DateTime?
UTC timestamp of when the setting expires. @TODO: Implement this.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ Id?
getter/setter pair
key ↔ String
The key
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String
The value
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited