PacmanPackageManager class

Inheritance

Constructors

PacmanPackageManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String name) Future<NativePackage?>
override
getAurExecutable() Future<String?>
Get AUR executable (for tests)
getInstalledDetails(String name) Future<Map<String, String>?>
Get detailed installed package information
getPacmanExecutable() Future<String>
Get the pacman executable path (fallback only)
install(String name, {bool a = true}) Future<void>
override
isInstalled(String name) Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseAurOutput(String output) List<NativePackage>
Parse AUR search output (legacy method, kept for compatibility)
parsePackageInfo(String output) NativePackage
Parse package information output
parseSearchOutput(String output, {int? limit}) List<NativePackage>
Parse search output (for tests)
override
toString() String
A string representation of this object.
inherited
updateDatabase() Future<void>
Update package database

Operators

operator ==(Object other) bool
The equality operator.
inherited