NativePackage class

Constructors

NativePackage({required String name, String? version, String? description, String? arch, String? repo, int? popularity})

Properties

arch → String?
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
popularity → int?
final
repo → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited