Shortcut class

A class that represents a shortcut to an executable file. This class is used to create shortcuts on the system. Currently, only Linux, macOS and Windows are supported.

Constructors

Shortcut({required String name, String? executablePath, String? icon, String? comment, bool? terminal = false, String? type = 'Application', String? categories, String? mime, bool startup = true, String? destination, bool sudo = true})

Properties

categories → String?
final
comment → String?
final
destination → String?
final
executablePath → String?
final
hashCode → int
The hash code for this object.
no setterinherited
home ↔ String
getter/setter pair
icon → String?
final
mime → String?
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startup → bool
final
sudo → bool
final
terminal → bool?
final
type → String?
final

Methods

create() → Future<String>
Creates the shortcut.
delete() → Future<bool>
Deletes the shortcut.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited